@@ -3,7 +3,6 @@
 ;;;  representations for parts of an imported Quicken file.  
 ;;;
 ;;;  Bill Gribble <grib@billgribble.com> 20 Feb 2000 
-;;;  $Id: qif-objects.scm,v 1.1.4.3 2004/10/13 15:12:53 warlord Exp $
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 
@@ -297,16 +296,16 @@
   (define (set-amounts neg? amounts)
     (map 
      (lambda (split amount)
-       (qif-split:set-amount! split (if neg? (gnc:numeric-neg amount) amount)))
+       (qif-split:set-amount! split (if neg? (gnc-numeric-neg amount) amount)))
      (qif-xtn:splits self) amounts))
 
   (define (need-neg amounts)
-    (let ((sum (gnc:numeric-zero)))
+    (let ((sum (gnc-numeric-zero)))
       (for-each
        (lambda (amt)
-	 (set! sum (gnc:numeric-add sum amt 0 GNC-DENOM-LCD)))
+	 (set! sum (gnc-numeric-add sum amt 0 GNC-DENOM-LCD)))
        amounts)
-      (gnc:numeric-zero-p sum)))
+      (gnc-numeric-zero-p sum)))
 
   (let ((def-spl (qif-xtn:default-split self)))
     (if def-spl
@@ -553,10 +552,12 @@
        (cond 
         ((memv t (list GNC-BANK-TYPE GNC-CASH-TYPE GNC-CCARD-TYPE 
                        GNC-STOCK-TYPE GNC-MUTUAL-TYPE
-                       GNC-ASSET-TYPE GNC-LIABILITY-TYPE))
+                       GNC-ASSET-TYPE GNC-LIABILITY-TYPE
+                       GNC-RECEIVABLE-TYPE GNC-PAYABLE-TYPE))
          (add-types GNC-BANK-TYPE GNC-CASH-TYPE GNC-CCARD-TYPE 
                     GNC-STOCK-TYPE GNC-MUTUAL-TYPE
-                    GNC-ASSET-TYPE GNC-LIABILITY-TYPE))
+                    GNC-ASSET-TYPE GNC-LIABILITY-TYPE
+                    GNC-RECEIVABLE-TYPE GNC-PAYABLE-TYPE))
         ((memv t (list GNC-INCOME-TYPE GNC-EXPENSE-TYPE))
          (add-types GNC-INCOME-TYPE GNC-EXPENSE-TYPE))
         (#t
@@ -662,7 +663,7 @@
    ticker-map
    (cons stock-symbol (qif-ticker-map:ticker-map ticker-map))))
 
-(define (qif-ticker-map:lookup-ticker ticker-map name)
+(define (qif-ticker-map:lookup-symbol ticker-map name)
   (let ((retval #f))
     (for-each 
      (lambda (symbol)
@@ -674,3 +675,15 @@
      (qif-ticker-map:ticker-map ticker-map))
     retval))
 
+(define (qif-ticker-map:lookup-type ticker-map name)
+  (let ((retval #f))
+    (for-each 
+     (lambda (symbol)
+       (if (string=? name (qif-stock-symbol:name symbol))
+	   (begin
+	     (set! retval (qif-stock-symbol:type symbol))
+	     (if (string=? retval "")
+		 (set! retval #f)))))
+     (qif-ticker-map:ticker-map ticker-map))
+    retval))
+
